@@ -11,6 +11,8 @@ testthat::test_that("providers.details structure", {
 
   testthat::expect_true(!is.null(providers_details_data[["OpenStreetMap"]][["variants"]]["Mapnik"]))
 
-  testthat::expect_equal(providers_details_data[["OpenStreetMap"]][["url"]],
-                         "//{s}.tile.openstreetmap.org/{z}/{x}/{y}.png")
+  testthat::expect_equal(
+    providers_details_data[["OpenStreetMap"]][["url"]],
+    "https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png"
+  )
 })
